@@ -84,7 +84,7 @@ extern "C" {
 #endif
 
 #define FI_MAJOR_VERSION 1
-#define FI_MINOR_VERSION 20
+#define FI_MINOR_VERSION 22
 #define FI_REVISION_VERSION 0
 
 enum {
@@ -118,11 +118,6 @@ struct fid_nic;
 
 typedef struct fid *fid_t;
 
-/*
- * Provider specific values are indicated by setting the high-order bit.
- */
-#define FI_PROV_SPECIFIC	(1U << 31)
-
 /*
  * Flags
  * The 64-bit flag field is used as follows:
@@ -153,7 +148,7 @@ typedef struct fid *fid_t;
 #define FI_PEEK			(1ULL << 19)
 #define FI_TRIGGER		(1ULL << 20)
 #define FI_FENCE		(1ULL << 21)
-#define FI_PRIORITY		(1ULL << 22)
+/* #define FI_PRIORITY		(1ULL << 22) */
 
 #define FI_COMPLETION		(1ULL << 24)
 #define FI_EVENT		FI_COMPLETION
@@ -169,11 +164,11 @@ typedef struct fid *fid_t;
 #define FI_MR_DMABUF		(1ULL << 40)
 #define FI_AV_USER_ID		(1ULL << 41)
 #define FI_PEER			(1ULL << 43)
-#define FI_XPU_TRIGGER		(1ULL << 44)
+/* #define FI_XPU_TRIGGER		(1ULL << 44) */
 #define FI_HMEM_HOST_ALLOC	(1ULL << 45)
 #define FI_HMEM_DEVICE_ONLY	(1ULL << 46)
 #define FI_HMEM			(1ULL << 47)
-#define FI_VARIABLE_MSG		(1ULL << 48)
+/* #define FI_VARIABLE_MSG		(1ULL << 48) */
 #define FI_RMA_PMEM		(1ULL << 49)
 #define FI_SOURCE_ERR		(1ULL << 50)
 #define FI_LOCAL_COMM		(1ULL << 51)
@@ -256,7 +251,8 @@ enum fi_mr_mode {
 enum fi_progress {
 	FI_PROGRESS_UNSPEC,
 	FI_PROGRESS_AUTO,
-	FI_PROGRESS_MANUAL
+	FI_PROGRESS_MANUAL,
+	FI_PROGRESS_CONTROL_UNIFIED,
 };
 
 enum fi_threading {
@@ -302,8 +298,8 @@ enum fi_ep_type {
 	FI_EP_MSG,
 	FI_EP_DGRAM,
 	FI_EP_RDM,
-	FI_EP_SOCK_STREAM,
-	FI_EP_SOCK_DGRAM,
+	/* FI_EP_SOCK_STREAM, */
+	/* FI_EP_SOCK_DGRAM, */
 };
 
 /* Endpoint protocol
@@ -346,6 +342,7 @@ enum {
 	FI_PROTO_COLL,
 	FI_PROTO_UCX,
 	FI_PROTO_SM2,
+	FI_PROTO_CXI_RNR,
 };
 
 enum {
@@ -376,8 +373,8 @@ static inline uint8_t fi_tc_dscp_get(uint32_t tclass)
 #define FI_ASYNC_IOV		(1ULL << 57)
 #define FI_RX_CQ_DATA		(1ULL << 56)
 #define FI_LOCAL_MR		(1ULL << 55)
-#define FI_NOTIFY_FLAGS_ONLY	(1ULL << 54)
-#define FI_RESTRICTED_COMP	(1ULL << 53)
+/* #define FI_NOTIFY_FLAGS_ONLY	(1ULL << 54) */
+/* #define FI_RESTRICTED_COMP	(1ULL << 53) */
 #define FI_CONTEXT2		(1ULL << 52)
 #define FI_BUFFERED_RECV	(1ULL << 51)
 /* #define FI_PEER_TRANSFER	(1ULL << 36) */
@@ -697,11 +694,7 @@ static inline int fi_alias(struct fid *fid, struct fid **alias_fid, uint64_t fla
 	return fi_control(fid, FI_ALIAS, &alias);
 }
 
-/* fid value names */
-/*
- * Currently no common name is defined. Provider specific names should
- * have the FI_PROV_SPECIFIC bit set.
- */
+/* Provider specific names should set the uppermost bit. */
 
 static inline int fi_get_val(struct fid *fid, int name, void *val)
 {
@@ -792,6 +785,12 @@ struct fi_param {
 int fi_getparams(struct fi_param **params, int *count);
 void fi_freeparams(struct fi_param *params);
 
+/* Dummy definitions for removed flags/caps/types. For compiling old fabtests */
+#define FI_VARIABLE_MSG		0ULL
+#define FI_NOTIFY_FLAGS_ONLY	0ULL
+#define FI_RESTRICTED_COMP	0ULL
+#define FI_EP_SOCK_STREAM	FI_EP_UNSPEC
+
 #ifdef FABRIC_DIRECT
 #include <rdma/fi_direct.h>
 #endif	/* FABRIC_DIRECT */
